@@ -351,22 +351,6 @@ def _main_(prog=None):
 
     import sys
 
-    # list of modules that should not be imported not to slow down the command line interface
-    DO_NOT_IMPORT = [
-        "pandas",
-        "mdtraj",
-        "numba",
-        "scipy"
-    ]
-
-    # check that heavy modules are not imported
-    for mod in DO_NOT_IMPORT:
-        if mod in sys.modules:
-            import warnings
-            msg = ("\n\nDo not import '" + mod + "' module by default in cli "
-                   "since it slows down startup of the application.\n")
-            warnings.warn(msg)
-
     # process command line arguments:
     # prog==None implies argv[0]
     sys.exit(cli(prog=prog, arguments=sys.argv[1:], use_argcomplete=True))
@@ -579,10 +563,30 @@ def _notify(**kargs):
 @arg("-S", "--sockname", help="screen sockname", default="cron")
 @arg("--python-exec", help="python executable", default="")
 @arg("--detach", help="detach screen", action="store_true")
-@arg("--period", help="detach screen", default=3600, type=int)
+@arg("--period", help="period (seconds)", default=3600, type=int)
+@arg("--max-times", help="maximum number of calls", default=None, type=int)
 def _cron(**kargs):
     from . import cron
     cron.cron(**kargs)
 
+@command("required", help="print requirements",
+         formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+@group(exclusive=True)
+@arg("--macports", help="conda syntax", action="store_true")
+@arg("--conda", help="macports syntax", action="store_true")
+@endgroup
+@arg("--pyver", help="pyversion (e.g. 38), for macports only", default="")
+def _required(macports: bool = False, conda: bool = False, pyver: str = ""):
+    if conda:
+        from . import required_conda
+        print(required_conda())
+    elif macports:
+        from . import required_macports
+        print(required_macports(pyver))
+    else:
+        from . import required_pip
+        print(required_pip())
+
+
 # Here we create a general eparser to be used from cli with prog=""
 _eparser = _create_eparser("")
